@@ -12,6 +12,6 @@ export HAVE_OPENCL=no
 export HAVE_QT=no
 export HAVE_VTK=yes
 #
-export CSF_OPT_INC="/usr/include/vtk/:/usr/include/FTGL:/usr/include/freetype2:/usr/include:/usr/include:"
-export CSF_OPT_LIB64="/usr/lib/:::/usr/lib:/usr/lib:"
+export CSF_OPT_INC="/opt/vtk6/include/vtk/:/usr/include/FTGL:/usr/include/freetype2:/usr/include:/usr/include:"
+export CSF_OPT_LIB64="/opt/vtk6/lib/:::/usr/lib:/usr/lib:"
 export CSF_OPT_BIN64=""
